<?php
if(!defined('VALID_CMS')) { die('ACCESS DENIED'); }

class cms_model_poster
{

    public function __construct()
    {
        $this->inDB   = cmsDatabase::getInstance();
        $this->inUser = cmsUser::getInstance();
        $this->inCore = cmsCore::getInstance();
        $this->config = $this->inCore->loadComponentConfig('poster');
        cmsCore::loadLanguage('components/poster');
    }

    public static function getDefaultConfig()
    {
        return array(
            'img_w'         => 650,
            'img_h'         => 650,
            'thumb_w'       => 150,
            'thumb_h'       => 150,
            'img_sqr'       => 0,
            'thumb_sqr'     => 1,
            'watermark'     => 0,
            'perpage'       => 10,
            'place_perpage' => 30,
            'perpage_block' => 60,
        );
    }

//    ******************* комменты
    public function getCommentTarget($target, $target_id) {

        $result = array();

        switch($target){
            case 'poster': $item = $this->inDB->get_fields('cms_poster_items', "id='{$target_id}'", 'seo_link, title');
                if (!$item) { return false; }
                $result['link']  = '/poster/'.$item['seo_link'];
                $result['title'] = $item['title'];
                break;
            case 'place': $item = $this->inDB->get_fields('cms_poster_place', "id='{$target_id}'", 'seo_link, title');
                if (!$item) { return false; }
                $result['link']  = '/poster/place/'.$item['seo_link'];
                $result['title'] = $item['title'];
                break;
        }

        return ($result ? $result : false);

    }

//    ******************* валидация

    //тип
    public function validateType($item)
    {
        $error = false;
        if($item['title']=='')
        {
            cmsCore::addSessionMessage('Заполните поле "Название"', 'error');
            $error = true;
        }

        if($error) return false;
        else return true;
    }

    //итем
    public function validateItem($item)
    {
        $error = false;

        if($item['title']=='')
        {
            cmsCore::addSessionMessage('Заполните поле "Название"', 'error');
            $error = true;
        }

        if($item['description']=='')
        {
            cmsCore::addSessionMessage('Заполните поле "Описание"', 'error');
            $error = true;
        }

        if($error) return false;
        else return true;
    }

    //место
    public function validatePlace($item)
    {
        $error = false;
        if($item['title']=='')
        {
            cmsCore::addSessionMessage('Заполните поле "Название"', 'error');
            $error = true;
        }
        if($item['city']=='')
        {
            cmsCore::addSessionMessage('Заполните поле "Город"', 'error');
            $error = true;
        }
        if($item['address']=='')
        {
            cmsCore::addSessionMessage('Заполните поле "Адрес"', 'error');
            $error = true;
        }

        if($error) return false;
        else return true;
    }

    //график
    public function validateSchedule($item)
    {
        $error = false;

        if($item['start_date']=='')
        {
            cmsCore::addSessionMessage('Заполните поле "Дата начала"', 'error');
            $error = true;
        }
        if($item['end_date']=='')
        {
            cmsCore::addSessionMessage('Заполните поле "Дата завершения"', 'error');
            $error = true;
        }

        if($error) return false;
        else return true;
    }

    //видео
    public function validateVideo($item)
    {
        $error = false;

        if($item['title']=='')
        {
            cmsCore::addSessionMessage('Заполните поле "Название"', 'error');
            $error = true;
        }
        if($item['code']=='')
        {
            cmsCore::addSessionMessage('Заполните поле "Ссылка на видео"', 'error');
            $error = true;
        }

        if($error) return false;
        else return true;
    }
//    ******************* типы итемов

    /**
     * берем список типов для итемов
     * @return array|bool
     */
    public function getTypeList()
    {
        $items = $this->inDB->get_table('cms_poster_type','is_visible=1','*');
        if($items)
        {
            $new_items = array();
            foreach($items as $item)
            {
                $item['image']      = (file_exists(PATH.'/images/poster/small/poster_type_'.$item['id'].'.jpg') ? '/images/poster/small/poster_type_'.$item['id'].'.jpg' : '');
                $item['count']      = $this->inDB->rows_count('cms_poster_items', 'type_id='.$item['id']);
                $new_items[] = $item;
            }
            $items = $new_items;
        }

        return $items;
    }

    /**
     * берем тип
     * @param bool $id
     * @param bool $url
     * @return array|bool|null
     */
    public function getType($id = false, $url = false)
    {
        $item = $this->inDB->get_fields('cms_poster_type', ($id>0 ? 'id='.$id : 'seo_link="'.$url.'"'), '*');

        return $item;
    }

    /**
     * сщхраниее типа
     * @param $type
     * @return bool
     */
    public function saveType($type)
    {
        if($this->validateType($type)=== true)
        {
            $type['seo_link'] = cmsCore::strToURL($type['title']);

            if($type['id'])
                $id = $this->inDB->update('cms_poster_type', $type, $type['id']);
            else
                $id = $this->inDB->insert('cms_poster_type', $type);

            $file = 'poster_type_'.$id.'.jpg';
            cmsCore::loadClass('upload_photo');
            $inUploadPhoto = cmsUploadPhoto::getInstance();
            // Выставляем конфигурационные параметры
            $inUploadPhoto->upload_dir    = PATH.'/images/poster/';
            $inUploadPhoto->small_size_w  = $this->config['thumb_w'];
            $inUploadPhoto->medium_size_w = $this->config['img_w'];
            $inUploadPhoto->thumbsqr      = $this->config['img_sqr'];
            $inUploadPhoto->is_watermark  = $this->config['watermark'];
            $inUploadPhoto->input_name    = 'image';
            $inUploadPhoto->filename      = $file;
            // Процесс загрузки фото
            $inUploadPhoto->uploadPhoto();

            return true;
        }
        else {
            return false;
        }
    }

    /**
     * удаление типа мероприятия
     * @param $id
     */
    public function deleteItemType($id)
    {
        $type = $this->getType($id);

        if($type)
        {
            $this->inDB->delete('cms_poster_type', 'id='.$type['id']);

            $items = $this->inDB->get_table('cms_poster_items','type_id='.$type['id']);

            if($items)
                foreach($items as $item)
                {
                    $this->deleteItem($item['id']);
                }
        }
    }

//    ******************* итемы
    /**
     * берем первые буквы из названия итемов
     * @param $type_id
     * @return string
     */
    function getAlphaList($type_id){
        $html = '';
        $sql = "SELECT UPPER(SUBSTRING(LTRIM( title ) , 1, 1)) AS first_letter, COUNT( id ) AS num
            FROM cms_poster_items
            WHERE type_id = '$type_id' AND is_visible = 1
            GROUP BY first_letter";

        $result = $this->inDB->query($sql) ;
        if ($this->inDB->num_rows($result)){
            $html .= '<div class="poster-alpha-list">';
            while($a = $this->inDB->fetch_assoc($result)){
                if(preg_match('/^([a-zA-Zа-яёіїєґА-ЯЁІЇЄҐ0-9]+)$/ui', $a['first_letter'])){
                    $html .= '<a  href="" >'.$a['first_letter'].'</a>';
                }
            }
            $html .= '</div>';
        }
        return $html;
    }

    /***
     * количество итемов
     * @return int
     */
    public function getItemsTotal()
    {
        $sql = "
                SELECT
                i.*,
                t.title as type_title,
                t.seo_link as type_seo_link
                FROM cms_poster_items i
                LEFT JOIN cms_poster_type t ON i.type_id = t.id
                LEFT JOIN cms_poster_schedule s ON i.id = s.item_id
                WHERE
                {$this->inDB->where}
                GROUP BY i.id
                {$this->inDB->order_by}
                ";

        $result = $this->inDB->query($sql);
        return $this->inDB->num_rows($result);
    }

    /**
     * список итемов
     * @return array|bool
     */
    public function getItems()
    {
        $items = array();

        $sql = "SELECT
                i.*,
                t.title as type_title,
                t.seo_link as type_seo_link
                FROM cms_poster_items i
                LEFT JOIN cms_poster_type t ON i.type_id = t.id
                LEFT JOIN cms_poster_schedule s ON i.id = s.item_id
                WHERE
                {$this->inDB->where}
                GROUP BY i.id
                {$this->inDB->order_by}
                ";

        if ($this->inDB->limit) $sql .= "LIMIT {$this->inDB->limit}";

        $result = $this->inDB->query($sql);
        $this->inDB->resetConditions();

        if (!$this->inDB->num_rows($result))  return false;

        while ($item = $this->inDB->fetch_assoc($result)){
            $item['image']    = (file_exists(PATH.'/images/poster/small/poster_item_'.$item['id'].'.jpg') ? '/images/poster/small/poster_item_'.$item['id'].'.jpg' : '');
            $item['visited']  = $this->getVisitedCount($item['id']);
            $item['comments'] = cmsCore::getCommentsCount('poster', $item['id']);
            $item['schedules'] = $this->getItemAllSchedule($item['id']);
            $items[] = $item;
        }

        return $items;
    }

    /**
     * берем итем или по ИД или по СЕО линку
     * @param bool $id
     * @param bool $url
     * @return array|bool|null
     */
    public function getItem($id = false, $url = false)
    {
        $item = $this->inDB->get_fields('cms_poster_items', ($id>0 ? 'id='.$id : 'seo_link="'.$url.'"'), '*');
        if($item)
        {
            $item['image']    = (file_exists(PATH.'/images/poster/medium/poster_item_'.$item['id'].'.jpg') ? '/images/poster/medium/poster_item_'.$item['id'].'.jpg' : '');
            $item['user_voted'] = $this->isUserVoted($item['id'], $this->inUser->id, 'item');
            $item['images'] = unserialize($item['images']);
            $item['visited']  = $this->getVisitedCount($item['id']);
            $item['comments'] = cmsCore::getCommentsCount('poster', $item['id']);
            $item['videos'] = $this->getItemVideos($item['id']);

            if($_SESSION['item_id']!=$item['id'])
            {
                $_SESSION['item_id']=$item['id'];
                $view['view'] = ($item['view'] ? $item['view'] : 0)+1;
                $this->inDB->update('cms_poster_items', $view, $item['id']);
            }
        }

        return $item;
    }

    /**
     * сохранаяем итем
     * @param $item
     * @return mixed
     */
    public function saveItem($item)
    {
        $item['seo_link']   = cmsCore::strToURL($item['title']);
        $item['start_date'] = date('Y-m-d', strtotime($item['start_date']));
        $item['end_date']   = date('Y-m-d', strtotime($item['end_date']));

        if($item['is_premier']=='on')
            $item['is_premier'] = 1;
        else
            $item['is_premier'] = 0;

        if(!$item['user_id'])
            $item['user_id'] = $this->inUser->id;

        $item = $this->clearSpecChars($item);

        if($item['id'])
           $this->inDB->update('cms_poster_items', $item, $item['id']);
        else
        {
            $item['id'] = $this->inDB->insert('cms_poster_items', $item);
            $type = $this->getType($item['type_id']);

            cmsActions::log('add_poster', array(
                'object' => $item['title'],
                'object_url' => '/poster/'.$type['seo_link'].'/'.$item['seo_link'],
                'object_id' => $item['id'],
                'target' => $item['title'],
                'target_url' => '/poster/'.$type['seo_link'].'/'.$item['seo_link'],
                'target_id' => $item['id'],
                'description' => $item['title']
            ));
        }


        $file = 'poster_item_'.$item['id'].'.jpg';
        cmsCore::loadClass('upload_photo');
        $inUploadPhoto = cmsUploadPhoto::getInstance();
        $inUploadPhoto->upload_dir    = PATH.'/images/poster/';
        $inUploadPhoto->small_size_w  = $this->config['thumb_w'];
        $inUploadPhoto->medium_size_w = $this->config['img_w'];
        $inUploadPhoto->thumbsqr      = $this->config['img_sqr'];
        $inUploadPhoto->is_watermark  = $this->config['watermark'];
        $inUploadPhoto->input_name    = 'image';
        $inUploadPhoto->filename      = $file;
        $inUploadPhoto->uploadPhoto();

        $this->saveImages('item', $item['id']);

        return $item;
    }


    /**
     * сохраняем дополнительные картинки к итему
     * @param $target
     * @param $target_id
     */
    public function saveImages($target, $target_id)
    {
        $inCore = cmsCore::getInstance();
        $inCore->includeGraphics();

        $uploaddir      = $_SERVER['DOCUMENT_ROOT'].'/images/poster/';
        $loaded_files   = array();
        $list_files     = array();

        foreach($_FILES['upfile'] as $key=>$value) {
            foreach($value as $k=>$v) { $list_files['upfile'.$k][$key] = $v; }
        }

        foreach ($list_files as $key=>$data_array) {
            if ($key != 'imgfile' && $key != 'imgfile_small' && $key != 'itemfile' && !mb_strstr($key, 'char_file')){
                $error = $data_array['error'];
                if ($error == UPLOAD_ERR_OK) {

                    $tmp_name       = $data_array['tmp_name'];
                    $filename       = md5(microtime()).'.jpg';

                    $uploadphoto    = $uploaddir . $filename;
                    $uploadthumb    = $uploaddir . 'small/' . $filename;
                    $uploadthumb2   = $uploaddir . 'medium/' . $filename;

                    if (@move_uploaded_file($tmp_name, $uploadphoto)){
                        @img_resize($uploadphoto, $uploadthumb, $this->config['thumb_w'], $this->config['thumb_h'], $this->config['img_sqr']);
                        @img_resize($uploadphoto, $uploadthumb2, $this->config['img_w'], $this->config['img_h'], false, $this->config['watermark']);
                        @unlink($uploadphoto);
                        if ($this->config['watermark']) { @img_add_watermark($uploadthumb2);}
                        $loaded_files[] = $filename;
                    }

                }
            }
        }

        if($target=='item')
        {
            $img = unserialize($this->inDB->get_field('cms_poster_items', 'id='.$target_id, 'images'));

            $images['images'] = serialize(($img ?array_merge($img, $loaded_files) : $loaded_files));
            $this->inDB->update('cms_poster_items', $images, $target_id);
        }

        if($target=='place')
        {
            $img = unserialize($this->inDB->get_field('cms_poster_place', 'id='.$target_id, 'images'));

            $images['images'] = serialize(($img ?array_merge($img, $loaded_files) : $loaded_files));
            $this->inDB->update('cms_poster_place', $images, $target_id);
        }
    }

    public function deleteItem($item_id)
    {
        $item = $this->getItem($item_id);
        if($item)
        {
            $this->inDB->delete('cms_poster_items', 'id='.$item_id);
            $this->inDB->delete('cms_poster_schedule', 'item_id='.$item_id);
            $this->inDB->delete('cms_comments', 'target="poster" AND target_id='.$item_id);
            $this->inDB->delete('cms_poster_ratings', 'target="poster" AND item_id='.$item_id);

            $this->deleteImage('poster_item_'.$item['id'].'.jpg');

            if(is_array(unserialize($item['images'])))
                foreach(unserialize($item['images']) as $image)
                {
                    $this->deleteImage($image);
                }
            cmsCore::addSessionMessage('Удалено.');
        } else
            cmsCore::addSessionMessage('Ошибка удаления!', 'error');
    }

    /**
     * берем весь список расписаний к итему
     * @param $item_id
     * @return array|bool
     */
    public function getItemAllSchedule($item_id)
    {
        $items = array();
        $date = date('Y-m-d');

        $sql = "SELECT s.*,
                p.title as title,
                p.city as city,
                p.seo_link as seo_link
                FROM cms_poster_schedule s
                LEFT JOIN cms_poster_place p ON p.id = s.place_id
                WHERE
                s.item_id = {$item_id}
                AND DATE_FORMAT(s.end_date, '%Y-%m-%d')>='{$date}'
                GROUP BY s.place_id
                ";

        $result = $this->inDB->query($sql);
        $this->inDB->resetConditions();

        if (!$this->inDB->num_rows($result))  return false;

        while ($item = $this->inDB->fetch_assoc($result)){
            $items[] = $item;
        }

        return $items;
    }

    /**
     * берем список итемов по типу, дата показа: сегодня
     * @param $type_id
     * @return array|bool
     */
    public function getNawShowItemsByType($type_id)
    {
        $items = array();
        $date = date('Y-m-d');

        $sql = "SELECT i.*
                FROM cms_poster_items i
                LEFT JOIN cms_poster_schedule s ON i.id = s.item_id
                WHERE
                i.type_id = {$type_id}
                AND DATE_FORMAT(s.start_date, '%Y-%m-%d')<='{$date}' AND DATE_FORMAT(s.end_date, '%Y-%m-%d')>='{$date}'
                GROUP BY i.id
                ";

        $result = $this->inDB->query($sql);
        $this->inDB->resetConditions();

        if (!$this->inDB->num_rows($result))  return false;

        while ($item = $this->inDB->fetch_assoc($result)){
            $items[] = $item;
        }

        return $items;
    }
//    ******************* места

    /**
     * берем список мест
     * @return array|bool
     */
    public function getPlaceList()
    {
        $items = $this->inDB->get_table('cms_poster_place','is_visible=1','*');
        return $items;
    }

    /**
     * берем место или по ИД или по СЕО линку
     * @param bool $id
     * @param bool $url
     * @return array|bool|null
     */
    public function getPlace($id = false, $url = false)
    {
        $item = $this->inDB->get_fields('cms_poster_place', ($id>0 ? 'id='.$id : 'seo_link="'.$url.'"'), '*');
        if($item)
        {
            $item['image']    = (file_exists(PATH.'/images/poster/medium/poster_place_'.$item['id'].'.jpg') ? '/images/poster/medium/poster_place_'.$item['id'].'.jpg' : '');
            $item['user_voted'] = $this->isUserVoted($item['id'], $this->inUser->id, 'place');
            $item['images'] = unserialize($item['images']);
            $item['schedules'] = $this->getPlaceSchedule($item['id'], false);
            $item['all_schedules'] = $this->getPlaceAllSchedule($item['id'], false);

            if($_SESSION['place_id']!=$item['id'])
            {
                $_SESSION['place_id']=$item['id'];
                $view['view'] = ($item['view'] ? $item['view'] : 0)+1;
               $this->inDB->update('cms_poster_place', $view, $item['id']);
            }
        }

        return $item;
    }

    /**
     * берем график расписаний для места, если дата не указана - берем для текущей
     * @param $place_id
     * @param $date
     * @return array|bool
     */
    public function getPlaceSchedule($place_id, $date)
    {
        $items = array();

        if($date)
            $date = date('Y-m-d', $date);
        else
            $date = date('Y-m-d');

        $sql = "SELECT s.*,
                i.title as title,
                i.seo_link as seo_link,
                t.seo_link as type_seo_link
                FROM cms_poster_schedule s
                LEFT JOIN cms_poster_items i ON i.id = s.item_id
                LEFT JOIN cms_poster_type t ON i.type_id = t.id
                WHERE
                s.place_id = {$place_id}
                AND DATE_FORMAT(s.start_date, '%Y-%m-%d')<='{$date}' AND DATE_FORMAT(s.end_date, '%Y-%m-%d')>='{$date}'
                GROUP BY s.item_id
                ";

        $result = $this->inDB->query($sql);
        $this->inDB->resetConditions();

        if (!$this->inDB->num_rows($result))  return false;

        while ($item = $this->inDB->fetch_assoc($result)){
            $item['image']    = (file_exists(PATH.'/images/poster/small/poster_item_'.$item['item_id'].'.jpg') ? '/images/poster/small/poster_item_'.$item['item_id'].'.jpg' : '');
            $items[] = $item;
        }

        return $items;
    }

    /**
     * весь список расписаний для места
     * @param $place_id
     * @return array|bool
     */
    public function getPlaceAllSchedule($place_id)
    {
        $items = array();
        $date = date('Y-m-d');

        $sql = "SELECT s.*,
                i.title as title,
                i.seo_link as seo_link,
                t.seo_link as type_seo_link
                FROM cms_poster_schedule s
                LEFT JOIN cms_poster_items i ON i.id = s.item_id
                LEFT JOIN cms_poster_type t ON i.type_id = t.id
                WHERE
                s.place_id = {$place_id}
                AND DATE_FORMAT(s.end_date, '%Y-%m-%d')>='{$date}'
                GROUP BY s.item_id
                ";

        $result = $this->inDB->query($sql);
        $this->inDB->resetConditions();

        if (!$this->inDB->num_rows($result))  return false;

        while ($item = $this->inDB->fetch_assoc($result)){
            $item['image']    = (file_exists(PATH.'/images/poster/small/poster_item_'.$item['item_id'].'.jpg') ? '/images/poster/small/poster_item_'.$item['item_id'].'.jpg' : '');
            $items[] = $item;
        }

        return $items;
    }

    /**
     * сохраняем место
     * @param $item
     * @return mixed
     */
    public function savePlace($item)
    {
        $item['seo_link'] = cmsCore::strToURL($item['title']);

        if(!$item['user_id'])
            $item['user_id'] = $this->inUser->id;

        $address = "город ".$item['city'].", ".$item['address'];
        $address = urlencode($address);
        $url = "http://geocode-maps.yandex.ru/1.x/?geocode=".$address;
        $content = @file_get_contents($url);
        preg_match('/<pos>(.*?)<\/pos>/',$content,$point);
        $cord = explode(' ', $point[1]);
        $item['map_coords'] = $cord[1].', '.$cord[0];

        $item=$this->clearSpecChars($item);

        if($item['id'])
            $this->inDB->update('cms_poster_place', $item, $item['id']);
        else
        {
            $item['id'] = $this->inDB->insert('cms_poster_place', $item);

            cmsActions::log('add_place', array(
                'object' => $item['title'],
                'object_url' => '/poster/place/'.$item['seo_link'],
                'object_id' => $item['id'],
                'target' => $item['title'],
                'target_url' => '/poster/place/'.$item['seo_link'],
                'target_id' => $item['id'],
                'description' => $item['title']
            ));
        }


        $file = 'poster_place_'.$item['id'].'.jpg';
        cmsCore::loadClass('upload_photo');
        $inUploadPhoto = cmsUploadPhoto::getInstance();
        $inUploadPhoto->upload_dir    = PATH.'/images/poster/';
        $inUploadPhoto->small_size_w  = $this->config['thumb_w'];
        $inUploadPhoto->medium_size_w = $this->config['img_w'];
        $inUploadPhoto->thumbsqr      = $this->config['img_sqr'];
        $inUploadPhoto->is_watermark  = $this->config['watermark'];
        $inUploadPhoto->input_name    = 'image';
        $inUploadPhoto->filename      = $file;
        $inUploadPhoto->uploadPhoto();

        $this->saveImages('place', $item['id']);

        return $item;
    }

    /**
     * количество мест
     * @return int
     */
    public function getPlacesTotal()
    {
        $sql = "
                SELECT p.*
                FROM cms_poster_place p
                WHERE {$this->inDB->where}
                ";

        $result = $this->inDB->query($sql);
        return $this->inDB->num_rows($result);
    }

    /**
     * список мест
     * @return array|bool
     */
    public function getPlaces()
    {
        $items = array();

        $sql = "SELECT
                p.*,
                t.title as place_type
                FROM cms_poster_place p
                LEFT JOIN cms_poster_place_type t ON p.type_id = t.id
                WHERE
                {$this->inDB->where}
                {$this->inDB->order_by}\n";

        if ($this->inDB->limit) $sql .= "LIMIT {$this->inDB->limit}";

        $result = $this->inDB->query($sql);
        $this->inDB->resetConditions();

        if (!$this->inDB->num_rows($result))  return false;

        while ($item = $this->inDB->fetch_assoc($result)){
            $item['image']    = (file_exists(PATH.'/images/poster/small/poster_place_'.$item['id'].'.jpg') ? '/images/poster/small/poster_place_'.$item['id'].'.jpg' : '');
            $items[] = $item;
        }

        return $items;
    }

    /**
     * список мест для карты
     * @return string
     */
    public function getPlacesForMap()
    {
        $items = $this->getPlaces();
        $names = array();

        foreach($items as $item) {
            if($item['map_coords'])
            {
                $coords = explode(', ', $item['map_coords']);
                $data['type'] = 'Feature';
                $data['geometry'] = array(
                    'type'=>'Point',
                    'coordinates' => array($coords[0], $coords[1]),
                );

                $data['properties'] = array(
                    'balloonContentHeader'=> $item['title'],
                    'balloonContentBody'=> $item['description'],
                    'balloonContentFooter'=> '<a href="/poster/place/'.$item['seo_link'].'">Подробнее</a>',
                    'hintContent'=> $item['title'],
                );
                $data['options'] = array(
                    'preset'=>'twirl#nightDotIcon',
                );
                $names[] = $data;
            }
        }

        $places = array(
            'type'=> 'FeatureCollection',
            'features'=> $names
        );

        return json_encode($places);
    }

    /**
     * список городов мест
     * @return array|bool
     */
    public function getPlaceCity()
    {
        $items = array();

        $sql = "SELECT city
                FROM cms_poster_place
                GROUP BY city
                ";

        $result = $this->inDB->query($sql);
        if (!$this->inDB->num_rows($result))  return false;

        while ($item = $this->inDB->fetch_assoc($result)){
            $items[] = $item;
        }

        return $items;
    }

    public function deletePlace($place_id)
    {
        $item = $this->getPlace($place_id);
        if($item)
        {
            $this->inDB->delete('cms_poster_place', 'id='.$place_id);
            $this->inDB->delete('cms_poster_schedule', 'place_id='.$place_id);
            $this->inDB->delete('cms_comments', 'target="place" AND target_id='.$place_id);
            $this->inDB->delete('cms_poster_ratings', 'target="place" AND item_id='.$place_id);

            $this->deleteImage('poster_place_'.$item['id'].'.jpg');

            if(is_array(unserialize($item['images'])))
                foreach(unserialize($item['images']) as $image)
                {
                    $this->deleteImage($image);
                }
            cmsCore::addSessionMessage('Удалено.');
        } else
            cmsCore::addSessionMessage('Ошибка удаления!', 'error');
    }
//    ******************* графики
    /**
     * сохранение расписания
     * @param $item
     * @return mixed
     */
    public function saveSchedule($item)
    {
        $item['start_date'] = date('Y-m-d', strtotime($item['start_date']));
        $item['end_date'] = date('Y-m-d', strtotime($item['end_date']));

        if($item['id'])
            $this->inDB->update('cms_poster_schedule', $item, $item['id']);
        else
            $item['id'] = $this->inDB->insert('cms_poster_schedule', $item);

        return $item;
    }

    /**
     * берем расписание по ИД
     * @param $id
     * @return array|bool|null
     */
    public function getSchedule($id)
    {
        $item = $this->inDB->get_fields('cms_poster_schedule', 'id='.$id, '*');

        return $item;
    }

    /**
     * берем список расписаний для итема по дате, ясли дата не указана - берем текущую
     * @param $item_id
     * @param $date
     * @return array|bool
     */
    public function getSchedules($item_id, $date)
    {
        $items = array();
        if($date)
            $date = date('Y-m-d', $date);
        else
            $date = date('Y-m-d');

        if($item_id)
            $where = " s.item_id = {$item_id} ";
        else
            $where = " 1=1 ";

        $sql = "
            SELECT
            s.*,
            p.title as title,
            p.city as city,
            p.id as p_id,
            p.seo_link as seo_link
            FROM cms_poster_schedule s
            LEFT JOIN cms_poster_place p ON p.id = s.place_id
            WHERE
            {$where}
            AND DATE_FORMAT(s.start_date, '%Y-%m-%d')<='{$date}' AND DATE_FORMAT(s.end_date, '%Y-%m-%d')>='{$date}'
            GROUP BY s.place_id
        ";

        $result = $this->inDB->query($sql);

        if (!$this->inDB->num_rows($result))  return false;

        while ($item = $this->inDB->fetch_assoc($result)){
            $item['image']    = (file_exists(PATH.'/images/poster/small/poster_place_'.$item['p_id'].'.jpg') ? '/images/poster/small/poster_place_'.$item['p_id'].'.jpg' : '');
            $items[] = $item;
        }

        return $items;
    }

    public function getAllSchedules($date, $month=false)
    {
        $items = array();
        if($date)
            $date = date('Y-m-d', strtotime($date));
        else
            $date = date('Y-m-d');

        $where = " 1=1 ";

        if(!$month)
            $where.="AND DATE_FORMAT(s.start_date, '%Y-%m-%d')<='{$date}' AND DATE_FORMAT(s.end_date, '%Y-%m-%d')>='{$date}'";
        else
            $where.="AND (EXTRACT(MONTH FROM s.start_date) = DATE_FORMAT(NOW(), '%c')) OR (EXTRACT(MONTH FROM s.end_date) = DATE_FORMAT(NOW(), '%c'))";

        $sql = "
            SELECT
            s.*,
            s.price as s_price,
            p.title as p_title,
            p.city as city,
            p.seo_link as p_seo_link,
            i.id as i_id,
            t.title as type_title,
            t.seo_link as type_seo_link,
            i.*
            FROM cms_poster_schedule s
            LEFT JOIN cms_poster_place p ON p.id = s.place_id
            LEFT JOIN cms_poster_items i ON i.id = s.item_id
            LEFT JOIN cms_poster_type t ON t.id = i.type_id
            WHERE
            {$where}
            GROUP BY s.item_id
            ORDER BY p.title
        ";

        if ($this->inDB->limit) $sql .= "LIMIT {$this->inDB->limit}";

        $result = $this->inDB->query($sql);

        if (!$this->inDB->num_rows($result))  return false;

        while ($item = $this->inDB->fetch_assoc($result)){
            $item['image']    = (file_exists(PATH.'/images/poster/small/poster_item_'.$item['i_id'].'.jpg') ? '/images/poster/small/poster_item_'.$item['i_id'].'.jpg' : '');
            $items[] = $item;
        }

        return $items;
    }


    public function deleteSchedule($id)
    {
        $this->inDB->delete('cms_poster_schedule', 'id='.$id);
        cmsCore::addSessionMessage('Удалено.');
    }
//    ******************* "я пойду"
    /**
     * проверка пойдет ли текущий юзверь
     * @param $item_id
     * @return bool
     */
    public function checkVisited($item_id)
    {
        if($item_id)
            return $this->inDB->get_field('cms_poster_visited', 'user_id='.$this->inUser->id.' AND item_id='.$item_id, 'id');

        return false;
    }

    /**
     * количество "я пойду" для итема
     * @param $item_id
     * @return int|string
     */
    public function getVisitedCount($item_id)
    {
        if($item_id)
            return $this->inDB->rows_count('cms_poster_visited', 'item_id='.$item_id);

        return '0';
    }

    /**
     * список тех кто пойдет для итема
     * @param $item_id
     * @return array|bool
     */
    public function getVisitedList($item_id)
    {
        $items = array();
        $sql = "
            SELECT
            v.*,
            p.*,
            u.nickname as nickname,
            u.login as login
            FROM cms_poster_visited v
            LEFT JOIN cms_users u ON u.id = v.user_id
            LEFT JOIN cms_user_profiles p ON u.id = p.user_id
            WHERE v.item_id = {$item_id}
        ";

        $result = $this->inDB->query($sql);

        if (!$this->inDB->num_rows($result))  return false;

        while ($item = $this->inDB->fetch_assoc($result)){
           $item['avatar']    = $this->inUser->getUserAvatarUrl($item['user_id'], 'small', $item['imageurl']);
           $items[] = $item;
        }

        return $items;
    }
//    ******************* рейтинги
    /**
     * рейтинг для итема и места
     * @param $item_id
     * @param $user_id
     * @param $target
     * @return bool
     */
    public function isUserVoted($item_id, $user_id, $target) {

        return (bool)$this->inDB->rows_count('cms_poster_ratings', "target='{$target}' AND item_id={$item_id} AND user_id={$user_id}", 1);

    }

    /**
     * рейтинг для итема и места
     * @param $item_id
     * @param $user_id
     * @param $points
     * @param $target
     * @return bool
     */
    public function rateItem($item_id, $user_id, $points, $target){

        $inUser = cmsUser::getInstance();

        if (!$item_id) { return false; }
        if (!$inUser->id || ($user_id != $inUser->id)) { return false; }
        if ($this->isUserVoted($item_id, $user_id, $target)) { return false; }

        $sql = "INSERT INTO cms_poster_ratings (`item_id`, `user_id`, `points`, `target`)
                VALUES('{$item_id}', '{$user_id}', '{$points}', '{$target}')";

        $this->inDB->query($sql);

        $sql = "SELECT COUNT(user_id) as rating_votes,
                       AVG(points) as rating
                FROM cms_poster_ratings
                WHERE item_id = {$item_id} AND target = '{$target}'
                GROUP BY item_id";

        $rate_res   = $this->inDB->query($sql);
        $data       = $this->inDB->fetch_assoc($rate_res);

        $data['rating'] = round($data['rating'], 2);

        if($target=='item')
            $this->inDB->query("UPDATE cms_poster_items SET rating = '{$data['rating']}', rating_votes = '{$data['rating_votes']}' WHERE id={$item_id} LIMIT 1");
        if($target=='place')
            $this->inDB->query("UPDATE cms_poster_place SET rating = '{$data['rating']}', rating_votes = '{$data['rating_votes']}' WHERE id={$item_id} LIMIT 1");

        return true;

    }
// ********************* видео

    /**
     * берем список видео по ИД итема
     * @param $item_id
     * @return array|bool
     */
    public function getItemVideos($item_id){
        $items = $this->inDB->get_table('cms_poster_video', 'item_id='.$item_id, '*');

        return $items;
    }

    /**
     * берем видео по ИД
     * @param $id
     * @return array|bool|null
     */
    public function getVideo($id)
    {
        $item = $this->inDB->get_fields('cms_poster_video', 'id='.$id, '*');

        return $item;
    }

    /**
     * сохранение видео
     * @param $item
     * @return mixed
     */
    public function saveVideo($item)
    {

        $item['code'] = $this->getTubeLink($item['code']);
        if($item['id'])
            $this->inDB->update('cms_poster_video', $item, $item['id']);
        else
            $item['id'] = $this->inDB->insert('cms_poster_video', $item);

        return $item;

    }

    /**
     * обработка ссылки из YouTube
     * @param $link
     * @return array|string
     */
    public function getTubeLink($link)
    {
        $result = '';
        $pattern1 = '/youtube/';
        $pattern2 = '/youtu.be/';

        $res1 = preg_match($pattern1,$link);
        $res2 = preg_match($pattern2,$link);

        if($res1){

            $link = explode('=',$link);

            if(is_array($link)){
                if(count($link)==4)
                {
                    $link = $link[2];
                    $link = explode('&',$link);
                    $link = $link['0'];
                }
                elseif(count($link)==3)
                {
                    $link = explode('&',$link[1]);
                    $link = $link['0'];
                }
                elseif(count($link)==2)
                {
                    $link = $link[1];
                }
                return @$link;
            }
        } elseif(!$res1 && isset($res2)) {

            $link = explode('/', $link);

            if(count($link) == 4)

            {
                $result = $link[3];
            } elseif(count($link) == 2) {
                $result = $link[1];
            } elseif(count($link) == 1) {
                $result = $link[0];
            }
        }

        return $result;
    }
    //    ******************* типы мест

    /**
     * берем список типов для мест
     * @return array|bool
     */
    public function getPlaceTypeList()
    {
        $items = $this->inDB->get_table('cms_poster_place_type','is_visible=1','*');
        if($items)
        {
            $new_items = array();
            foreach($items as $item)
            {
                $item['image']    = (file_exists(PATH.'/images/poster/small/poster_type_place_'.$item['id'].'.jpg') ? '/images/poster/small/poster_type_place_'.$item['id'].'.jpg' : '');
                $new_items[] = $item;
            }
            $items = $new_items;
        }

        return $items;
    }

    /**
     * берем тип, или по Ид или по СЕО линку
     * @param bool $id
     * @param bool $url
     * @return array|bool|null
     */
    public function getPlaceType($id = false, $url = false)
    {
        $item = $this->inDB->get_fields('cms_poster_place_type', ($id>0 ? 'id='.$id : 'seo_link="'.$url.'"'), '*');

        return $item;
    }


    /**
     * удаление типа места, вместе с местами
     * @param $id
     */
    public function deletePlaceType($id)
    {
        $type = $this->getPlaceType($id);

        if($type)
        {
            $this->inDB->delete('cms_poster_place_type', 'id='.$type['id']);

            $items = $this->inDB->get_table('cms_poster_place','type_id='.$type['id']);

            if($items)
                foreach($items as $item)
                {
                    $this->deletePlace($item['id']);
                }
        }
    }

    /**
     * сохранение типа
     * @param $type
     * @return bool
     */
    public function savePlaceType($type)
    {
        if($this->validateType($type)=== true)
        {
            $type['seo_link'] = cmsCore::strToURL($type['title']);

            if($type['id'])
                $id = $this->inDB->update('cms_poster_place_type', $type, $type['id']);
            else
                $id = $this->inDB->insert('cms_poster_place_type', $type);

            $file = 'poster_type_place_'.$id.'.jpg';
            cmsCore::loadClass('upload_photo');
            $inUploadPhoto = cmsUploadPhoto::getInstance();
            // Выставляем конфигурационные параметры
            $inUploadPhoto->upload_dir    = PATH.'/images/poster/';
            $inUploadPhoto->small_size_w  = $this->config['thumb_w'];
            $inUploadPhoto->medium_size_w = $this->config['img_w'];
            $inUploadPhoto->thumbsqr      = $this->config['img_sqr'];
            $inUploadPhoto->is_watermark  = $this->config['watermark'];
            $inUploadPhoto->input_name    = 'image';
            $inUploadPhoto->filename      = $file;
            // Процесс загрузки фото
            $inUploadPhoto->uploadPhoto();

            return true;
        }
        else {
            return false;
        }
    }
    //
    public function clearSpecChars($item)
    {
        $arr = array();

        if(is_array($item))
        {
            foreach($item as $key=>$data)
            {
                $arr[$key] = cmsCore::badTagClear(cmsCore::strClear(str_replace("'", '"', $data), false));
            }
        } else
            return cmsCore::strClear($item, false);

        return $arr;
    }


    public function deleteImage($image)
    {

        @chmod($_SERVER['DOCUMENT_ROOT']."/images/poster/small/".$image, 0777);
        @chmod($_SERVER['DOCUMENT_ROOT']."/images/poster/medium/".$image, 0777);
        @unlink($_SERVER['DOCUMENT_ROOT']."/images/poster/small/".$image);
        @unlink($_SERVER['DOCUMENT_ROOT']."/images/poster/medium/".$image);

        return;
    }
}